@@ -11,7 +11,7 @@
 
 class LibraryItem;
 
-class MAINMODULE_EXPORT BJT : public Component, public eBJT
+class BJT : public Component, public eBJT
 {
     public:
         BJT( QString type, QString id );
@@ -22,7 +22,9 @@ class MAINMODULE_EXPORT BJT : public Component, public eBJT
 
         virtual void updateStep() override;
 
-        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget );
+        virtual void setPnp( bool pnp ) override;
+
+        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w ) override;
 };
 
 #endif
