@@ -26,49 +26,70 @@ IoComponent::IoComponent( QString type, QString id)
     m_inImp = 1e9;
     m_ouImp = 40;
 
-    //m_rndPD = false;
-    m_invInputs = false;
-    m_invOutputs  = false;
+    m_invInputs  = false;
+    m_invOutputs = false;
 
-    m_propSize = 1;
+    m_propSize  = 1;
     m_propDelay = 10*1000; // 10 ns
-    m_timeLH = 3000;
-    m_timeHL = 4000;
+    m_timeLH    = 3000;
+    m_timeHL    = 4000;
 }
 IoComponent::~IoComponent(){}
 
 QList<ComProperty*> IoComponent::inputProps()
 {
     return {
-new ComProperty( "", tr("Inputs:"),"","",0),
-new DoubProp<IoComponent>( "Input_High_V", tr("Low to High Threshold"),"V" , this, &IoComponent::inputHighV, &IoComponent::setInputHighV ),
-new DoubProp<IoComponent>( "Input_Low_V" , tr("High to Low Threshold"),"V" , this, &IoComponent::inputLowV,  &IoComponent::setInputLowV ),
-new DoubProp<IoComponent>( "Input_Imped" , tr("Input Impedance")      ,"MΩ", this, &IoComponent::inputImp,   &IoComponent::setInputImp ) };
+        new ComProperty( "", tr("Inputs:"),"","",0),
+
+        new DoubProp<IoComponent>("Input_High_V", tr("Low to High Threshold"), "V"
+                                 , this, &IoComponent::inputHighV, &IoComponent::setInputHighV ),
+
+        new DoubProp<IoComponent>("Input_Low_V", tr("High to Low Threshold"), "V"
+                                 , this, &IoComponent::inputLowV, &IoComponent::setInputLowV ),
+
+        new DoubProp<IoComponent>("Input_Imped", tr("Input Impedance"), "MΩ"
+                                 , this, &IoComponent::inputImp, &IoComponent::setInputImp ) };
 }
 
 QList<ComProperty*> IoComponent::outputProps()
 {
     return {
-new ComProperty( "", tr("Outputs:"),"","",0),
-new DoubProp<IoComponent>( "Out_High_V", tr("Output High Voltage"),"V", this, &IoComponent::outHighV, &IoComponent::setOutHighV ),
-new DoubProp<IoComponent>( "Out_Low_V" , tr("Output Low Voltage") ,"V", this, &IoComponent::outLowV,  &IoComponent::setOutLowV ),
-new DoubProp<IoComponent>( "Out_Imped" , tr("Output Impedance")   ,"Ω", this, &IoComponent::outImp,   &IoComponent::setOutImp ) };
+        new ComProperty("", tr("Outputs:"),"","",0),
+
+        new DoubProp<IoComponent>("Out_High_V", tr("Output High Voltage"), "V"
+                                 , this, &IoComponent::outHighV, &IoComponent::setOutHighV ),
+
+        new DoubProp<IoComponent>("Out_Low_V", tr("Output Low Voltage"), "V"
+                                 , this, &IoComponent::outLowV, &IoComponent::setOutLowV ),
+
+        new DoubProp<IoComponent>("Out_Imped", tr("Output Impedance"), "Ω"
+                                 , this, &IoComponent::outImp, &IoComponent::setOutImp ) };
 }
 
 QList<ComProperty*> IoComponent::outputType()
 {
     return {
-new BoolProp<IoComponent>( "Inverted"      , tr("Invert Outputs"),"", this, &IoComponent::invertOuts, &IoComponent::setInvertOuts, propNoCopy ),
-new BoolProp<IoComponent>( "Open_Collector", tr("Open Drain")    ,"", this, &IoComponent::openCol,    &IoComponent::setOpenCol   , propNoCopy )};
+        new BoolProp<IoComponent>("Inverted", tr("Invert Outputs"), ""
+                                 , this, &IoComponent::invertOuts, &IoComponent::setInvertOuts, propNoCopy ),
+
+        new BoolProp<IoComponent>("Open_Collector", tr("Open Drain"), ""
+                                 , this, &IoComponent::openCol, &IoComponent::setOpenCol   , propNoCopy )};
 }
 
 QList<ComProperty*> IoComponent::edgeProps()
 {
     return {
-new DoubProp<IoComponent>( "pd_n"  , tr("Propagation delay"),"_Gates", this, &IoComponent::propSize, &IoComponent::setPropSize ),
-new DoubProp<IoComponent>( "Tpd_ps", tr("Gate Delay"),"ps", this, &IoComponent::propDelay, &IoComponent::setPropDelay ),
-new DoubProp<IoComponent>( "Tr_ps" , tr("Rise Time") ,"ps", this, &IoComponent::riseTime,  &IoComponent::setRiseTime ),
-new DoubProp<IoComponent>( "Tf_ps" , tr("Fall Time") ,"ps", this, &IoComponent::fallTime,  &IoComponent::setFallTime ) };
+        new DoubProp<IoComponent>("pd_n"  , tr("Propagation delay"), "_Gates"
+                                 , this, &IoComponent::propSize, &IoComponent::setPropSize ),
+
+        new DoubProp<IoComponent>("Tpd_ps", tr("Gate Delay"), "ns"
+                                 , this, &IoComponent::propDelay, &IoComponent::setPropDelay ),
+
+        new DoubProp<IoComponent>("Tr_ps" , tr("Rise Time"), "ns"
+                                 , this, &IoComponent::riseTime,  &IoComponent::setRiseTime ),
+
+        new DoubProp<IoComponent>("Tf_ps" , tr("Fall Time"), "ns"
+                                 , this, &IoComponent::fallTime,  &IoComponent::setFallTime ) };
 }
 
 void IoComponent::initState()
@@ -78,7 +99,6 @@ void IoComponent::initState()
         m_outPin[i]->setStateZ( false );
         m_outPin[i]->setOutState( false );
     }
-    m_outsReady = true;
     m_nextOutVal = m_outValue = 0;
     while( !m_outQueue.empty()  ) m_outQueue.pop();
     while( !m_timeQueue.empty() ) m_timeQueue.pop();
@@ -86,11 +106,11 @@ void IoComponent::initState()
 
 void IoComponent::runOutputs()
 {
-    if( m_outQueue.empty() ) m_outValue = m_nextOutVal;
-    else{
-        m_outValue = m_outQueue.front();
-        m_outQueue.pop();
+    m_outValue = m_outQueue.front();
+    m_outQueue.pop();
 
+    if( !m_timeQueue.empty() )
+    {
         uint64_t nextTime = m_timeQueue.front()-Simulator::self()->circTime();
         m_timeQueue.pop();
         Simulator::self()->addEvent( nextTime, m_eElement );
@@ -101,30 +121,24 @@ void IoComponent::runOutputs()
         bool state = m_outValue & (1<<i);
         m_outPin[i]->scheduleState( state, 0 );
     }
-    m_outsReady = m_outQueue.empty();
 }
 
 void IoComponent::scheduleOutPuts( eElement* el )
 {
-    uint64_t delay = m_propDelay*m_propSize;
-
-    if( m_outsReady ) // Event when outputs already dispatched
+    if(  m_outQueue.empty() )
     {
         if( m_nextOutVal == m_outValue ) return;
+        Simulator::self()->addEvent( m_propDelay*m_propSize, el );
     }
-    else             // New Event while previous Event not dispatched
+    else          // New Event while previous Event not dispatched
     {
-        if( m_outQueue.empty() ) { if( m_nextOutVal == m_outValue ) return; }
-        else                     { if( m_nextOutVal == m_outQueue.back() ) return; }
-
-        uint64_t nextTime = Simulator::self()->circTime()+delay;
+        if( m_nextOutVal == m_outQueue.back() ) return;
+        uint64_t nextTime = Simulator::self()->circTime()+m_propDelay*m_propSize;
         m_timeQueue.push( nextTime );
-        m_outQueue.push( m_nextOutVal );
 
         m_eElement = el;
     }
-    if( delay ) Simulator::self()->addEvent( delay, el );
-    else runOutputs();
+    m_outQueue.push( m_nextOutVal );
 }
 
 void IoComponent::setInputHighV( double volt )
@@ -392,10 +406,12 @@ void IoComponent::setNumPins( std::vector<IoPin*>* pinList, uint pins
             pinList->at(i) = new IoPin( angle, QPoint( x, y ), pinId, i, this, mode );
             initPin( pinList->at(i) );
             if( mode == output && m_invOutputs ) pinList->at(i)->setInverted( true );
+            if( mode == input && m_invInputs ) pinList->at(i)->setInverted( true );
 
             if( !label.isEmpty() ) pinList->at(i)->setLabelText( label+num );
             pinList->at(i)->setLabelColor( QColor( 0, 0, 0 ) );
     }   }
+    setflip();
     Circuit::self()->update();
 }
 
@@ -438,8 +454,10 @@ void IoComponent::setHidden( bool hid, bool hidArea, bool hidLabel )
     Component::setHidden( hid, hidArea, hidLabel );
 }
 
-void IoComponent::paint( QPainter *p, const QStyleOptionGraphicsItem *option, QWidget *widget )
+void IoComponent::paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w )
 {
-    Component::paint( p, option, widget );
+    Component::paint( p, o, w );
     p->drawRect( m_area );
+
+    Component::paintSelected( p );
 }
