@@ -8,21 +8,23 @@
 #include "simulator.h"
 #include "iopin.h"
 
-Component* FlipFlopRS::construct( QObject* parent, QString type, QString id )
-{ return new FlipFlopRS( parent, type, id ); }
+#define tr(str) simulideTr("FlipFlopRS",str)
+
+Component* FlipFlopRS::construct( QString type, QString id )
+{ return new FlipFlopRS( type, id ); }
 
 LibraryItem* FlipFlopRS::libraryItem()
 {
     return new LibraryItem(
-        QCoreApplication::translate("FlipFlopRS", "FlipFlop RS" ),
+        tr("FlipFlop RS"),
         "Memory",
         "2to2.png",
         "FlipFlopRS",
         FlipFlopRS::construct );
 }
 
-FlipFlopRS::FlipFlopRS( QObject* parent, QString type, QString id )
-          : FlipFlopBase( parent, type, id )
+FlipFlopRS::FlipFlopRS( QString type, QString id )
+          : FlipFlopBase( type, id )
 {
     m_width  = 3;
     m_height = 4;
@@ -40,8 +42,8 @@ FlipFlopRS::FlipFlopRS( QObject* parent, QString type, QString id )
     m_resetPin = m_inPin[1];
     m_clkPin   = m_inPin[2];
 
-    setSrInv( true );                           // Inver Set & Reset pins
-    setClockInv( false );                        //Don't Invert Clock pin
+    setSrInv( true );       // Inver Set & Reset pins
+    setClockInv( false );   // Don't Invert Clock pin
     setTrigger( Clock );
 
     removeProperty("UseRS");
