@@ -11,17 +11,17 @@
 
 class LibraryItem;
 
-class MAINMODULE_EXPORT AndGate : public Gate
+class AndGate : public Gate
 {
     public:
-        AndGate( QObject* parent, QString type, QString id );
+        AndGate( QString type, QString id );
         ~AndGate();
         
-        static Component* construct( QObject* parent, QString type, QString id );
-        static LibraryItem *libraryItem();
+ static Component* construct( QString type, QString id );
+ static LibraryItem* libraryItem();
 
-        virtual QPainterPath shape() const;
-        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget ) override;
+        virtual QPainterPath shape() const override;
+        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w ) override;
 };
 
 #endif
