@@ -62,11 +62,11 @@ I2CToParallel::I2CToParallel( QString type, QString id )
     m_cCode = 0b01010000; // 0x50, 80
 
     addPropGroup( { tr("Main"), {
-new IntProp<I2CToParallel>("Control_Code", tr("I2C Address"),""
-                           , this, &I2CToParallel::cCode,   &I2CToParallel::setCcode,0,"uint" ),
+        new IntProp<I2CToParallel>("Control_Code", tr("I2C Address"),""
+                                   , this, &I2CToParallel::cCode,   &I2CToParallel::setCcode,0,"uint" ),
 
-new DoubProp<I2CToParallel>("Frequency", tr("I2C Frequency"),"_KHz"
-                           , this, &I2CToParallel::freqKHz, &I2CToParallel::setFreqKHz )
+        new DoubProp<I2CToParallel>("Frequency", tr("I2C Frequency"),"_kHz"
+                                   , this, &I2CToParallel::freqKHz, &I2CToParallel::setFreqKHz )
     }, 0} );
 }
 I2CToParallel::~I2CToParallel(){}
