@@ -15,7 +15,7 @@ class LibraryItem;
 class IoPin;
 class eNode;
 
-class MAINMODULE_EXPORT Lm555 : public Component, public eElement
+class Lm555 : public Component, public eElement
 {
     public:
 
@@ -30,7 +30,7 @@ class MAINMODULE_EXPORT Lm555 : public Component, public eElement
         virtual void voltChanged() override;
         virtual void runEvent() override;
         
-        virtual void paint( QPainter *p, const QStyleOptionGraphicsItem *option, QWidget *widget );
+        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w ) override;
 
     protected:
         IoPin* m_output;
