@@ -42,7 +42,7 @@ Dial::Dial( QString type, QString id )
     m_area     = m_areaComp;
 
     m_graphical = true;
-    m_linker    = true;
+    m_isLinker = true;
 
     m_minVal = 0;
     m_maxVal = 1000;
@@ -63,7 +63,7 @@ Dial::Dial( QString type, QString id )
         new IntProp<Dial>("Max_Val", tr("Maximum Value"), ""
                          , this, &Dial::maxVal, &Dial::setMaxVal ),
 
-        new IntProp<Dial>( "Steps", tr("Steps"), ""
+        new IntProp<Dial>("Steps", tr("Steps"), ""
                          , this, &Dial::steps, &Dial::setSteps )
     },0 } );
 
