@@ -2,11 +2,11 @@
 #define TEXTCOMPONENT_H
 
 #include "component.h"
-#include "linkable.h"
+#include "linkercomponent.h"
 
 class LibraryItem;
 
-class MAINMODULE_EXPORT TextComponent : public Component, public Linkable
+class TextComponent : public LinkerComponent
 {
     public:
         TextComponent( QString type, QString id );
@@ -50,7 +50,7 @@ class MAINMODULE_EXPORT TextComponent : public Component, public Linkable
         qreal opac() { return m_opac; }
         void setOpac( qreal op );
 
-        virtual void createLinks( QSet<Component*>*compList ) override;
+        virtual void createLinks( QList<Component*>*compList ) override;
         virtual void compSelected( Component* comp ) override;
         virtual void setLinkedString( QString str, int i=0 ) override;
         virtual void setLinkedValue( double v, int i=0 ) override;
@@ -59,10 +59,6 @@ class MAINMODULE_EXPORT TextComponent : public Component, public Linkable
 
     public slots:
         void updateGeometry(int, int, int);
-        void slotLinkComp() { Linkable::startLinking(); }
-
-    protected:
-        virtual void contextMenuEvent( QGraphicsSceneContextMenuEvent* event ) override;
 
     private:
         QGraphicsTextItem* m_text;
