@@ -17,21 +17,23 @@
 #include "doubleprop.h"
 #include "boolprop.h"
 
-Component* AudioOut::construct( QObject* parent, QString type, QString id )
-{ return new AudioOut( parent, type, id ); }
+#define tr(str) simulideTr("AudioOut",str)
+
+Component* AudioOut::construct( QString type, QString id )
+{ return new AudioOut( type, id ); }
 
 LibraryItem* AudioOut::libraryItem()
 {
     return new LibraryItem(
-        tr( "Audio Out" ),
+        tr("Audio Out"),
         "Other Outputs",
         "audio_out.png",
         "AudioOut",
         AudioOut::construct);
 }
 
-AudioOut::AudioOut( QObject* parent, QString type, QString id )
-        : Component( parent, type, id )
+AudioOut::AudioOut( QString type, QString id )
+        : Component( type, id )
         , eResistor( id )
 {
     m_area = QRect( -12, -24, 24, 40 );
@@ -39,15 +41,17 @@ AudioOut::AudioOut( QObject* parent, QString type, QString id )
     m_pin.resize( 2 );
     m_ePin[0] = m_pin[0] = new Pin( 180, QPoint(-16,-8), id+"-lPin", 0, this);
     m_pin[0]->setLabelColor( Qt::red );
-    m_pin[0]->setFontSize( 5 );
+    m_pin[0]->setFontSize( 9 );
     m_pin[0]->setLength( 6 );
-    m_pin[0]->setLabelText("➕");
+    m_pin[0]->setSpace( 1.7 );
+    m_pin[0]->setLabelText("+");
 
     m_ePin[1] = m_pin[1] = new Pin( 180, QPoint(-16,0), id+"-rPin", 1, this);
     m_pin[1]->setLabelColor( QColor( 0, 0, 0 ) );
-    m_pin[1]->setFontSize( 5 );
+    m_pin[1]->setFontSize( 9 );
     m_pin[1]->setLength( 6 );
-    m_pin[1]->setLabelText("➖");
+    m_pin[1]->setSpace( 1.7 );
+    m_pin[1]->setLabelText("–");  // U+2013
 
     setLabelPos(-20,-36, 0);
     
@@ -92,8 +96,11 @@ AudioOut::AudioOut( QObject* parent, QString type, QString id )
     m_audioOutput = new QAudioOutput( m_deviceinfo, m_format );
 
     addPropGroup( { tr("Main"), {
-new BoolProp<AudioOut>( "Buzzer"   , tr("Buzzer")   ,"" , this, &AudioOut::buzzer, &AudioOut::setBuzzer ),
-new DoubProp<AudioOut>( "Impedance", tr("Impedance"),"Ω", this, &AudioOut::res,    &AudioOut::setResSafe )
+        new BoolProp<AudioOut>("Buzzer", tr("Buzzer"), ""
+                              , this, &AudioOut::buzzer, &AudioOut::setBuzzer ),
+
+        new DoubProp<AudioOut>("Impedance", tr("Impedance"), "Ω"
+                              , this, &AudioOut::res, &AudioOut::setResSafe )
     },0} );
 }
 AudioOut::~AudioOut()
@@ -209,4 +216,6 @@ void AudioOut::paint( QPainter *p, const QStyleOptionGraphicsItem *option, QWidg
     if( m_deviceinfo.isNull() ){
         p->drawLine(0,-8, 7, 0 );
         p->drawLine( 7,-8,0, 0 );
-}   }
+    }
+    Component::paintSelected( p );
+}
