@@ -50,8 +50,11 @@ WS2812::WS2812( QString type, QString id )
     Simulator::self()->addToUpdateList( this );
 
     addPropGroup( { tr("Main"), {
-new IntProp<WS2812>( "Rows", tr("Rows")   ,"_Leds", this, &WS2812::rows, &WS2812::setRows,0,"uint" ),
-new IntProp<WS2812>( "Cols", tr("Columns"),"_Leds", this, &WS2812::cols, &WS2812::setCols,0,"uint" ),
+        new IntProp<WS2812>("Rows", tr("Rows"),""
+                           , this, &WS2812::rows, &WS2812::setRows,0,"uint" ),
+
+        new IntProp<WS2812>("Cols", tr("Columns"),""
+                           , this, &WS2812::cols, &WS2812::setCols,0,"uint" ),
     }, groupNoCopy} );
 }
 WS2812::~WS2812() { }
@@ -177,4 +180,7 @@ void WS2812::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget
         for( int col=0; col<m_cols; col++ ){
             p->setBrush( m_led[row*m_cols+col] );
             p->drawEllipse( -6+col*12, -6+row*12, 12, 12 );
-}   }   }
+    }   }
+
+    Component::paintSelected( p );
+}
