@@ -59,9 +59,14 @@ Servo::Servo( QString type, QString id )
     Simulator::self()->addToUpdateList( this );
 
     addPropGroup( { tr("Main"), {
-new DoubProp<Servo>( "Speed"   , tr("Speed ")     ,tr("_s/60º"), this, &Servo::speed,    &Servo::setSpeed ),
-new DoubProp<Servo>( "MinPulse", tr("Min. Pulse Width"),tr("_us"), this, &Servo::minPulse, &Servo::setMinPulse ),
-new DoubProp<Servo>( "MaxPulse", tr("Max. Pulse Width"),tr("_us"), this, &Servo::maxPulse, &Servo::setMaxPulse )
+        new DoubProp<Servo>("Speed", tr("Speed "), "_s/60º"
+                           , this, &Servo::speed, &Servo::setSpeed ),
+
+        new DoubProp<Servo>("MinPulse", tr("Min. Pulse Width"), "_µs"
+                           , this, &Servo::minPulse, &Servo::setMinPulse ),
+
+        new DoubProp<Servo>("MaxPulse", tr("Max. Pulse Width"), "_µs"
+                           , this, &Servo::maxPulse, &Servo::setMaxPulse )
     },0} );
     addPropGroup( { tr("Electric"), IoComponent::inputProps(),0 } );
 }
