@@ -36,8 +36,9 @@ RTD::RTD( QString type, QString id )
    : ThermistorBase( type, id )
 {
     addPropGroup( { tr("Parameters"), {
-//new IntProp<RTD>( "B" , "B" ,""  , this, &RTD::bVal, &RTD::setBval, "uint" ),
-new DoubProp<RTD>( "R0", "R0","Ω" , this, &RTD::getR0,   &RTD::setR0 )
+        //new IntProp<RTD>( "B" , "B" ,""  , this, &RTD::bVal, &RTD::setBval, "uint" ),
+        new DoubProp<RTD>("R0", "R0", "Ω"
+                         , this, &RTD::getR0, &RTD::setR0 )
     }, 0} );
     addPropGroup( { tr("Dial"), Dialed::dialProps(), groupNoCopy } );
 }
@@ -59,7 +60,7 @@ void RTD::updateStep()
     double res = sensorFunction( m_value );
     eResistor::setRes( res );
    if( m_propDialog ) m_propDialog->updtValues();
-   else if( m_showProperty == "Temp" ) setValLabelText( getPropStr( "Temp" ) );
+   else setValLabelText( getPropStr( showProp() ) );
     //m_lastTime = time;
 }
 
@@ -88,4 +89,6 @@ void RTD::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* w
 
     p->drawLine(-6, 6, 8,-8 );
     p->drawText(-8,-6, "+tº");
+
+    Component::paintSelected( p );
 }
