@@ -7,8 +7,10 @@
 
 #include "doubleprop.h"
 
-ThermistorBase::ThermistorBase( QObject* parent, QString type, QString id )
-              : VarResBase( parent, type, id  )
+#define tr(str) simulideTr("ThermistorBase",str)
+
+ThermistorBase::ThermistorBase( QString type, QString id )
+              : VarResBase( type, id  )
 {
     setValLabelPos(-16, 30, 0);
 
@@ -18,10 +20,17 @@ ThermistorBase::ThermistorBase( QObject* parent, QString type, QString id )
     setVal( 25 );
 
     addPropGroup( { tr("Main"), {
-new DoubProp<ThermistorBase>( "Temp"     , tr("Current Value"),"ºC", this, &ThermistorBase::getVal,  &ThermistorBase::setVal ),
-new DoubProp<ThermistorBase>( "Min_Temp" , tr("Minimum Value"),"ºC", this, &ThermistorBase::minVal,  &ThermistorBase::setMinVal ),
-new DoubProp<ThermistorBase>( "Max_Temp" , tr("Maximum Value"),"ºC", this, &ThermistorBase::maxVal,  &ThermistorBase::setMaxVal ),
-new DoubProp<ThermistorBase>( "Dial_Step", tr("Dial Step")    ,"ºC", this, &ThermistorBase::getStep, &ThermistorBase::setStep )
+        new DoubProp<ThermistorBase>("Temp", tr("Current Value"), "ºC"
+                                    , this, &ThermistorBase::getVal, &ThermistorBase::setVal ),
+
+        new DoubProp<ThermistorBase>("Min_Temp", tr("Minimum Value"), "ºC"
+                                    , this, &ThermistorBase::minVal, &ThermistorBase::setMinVal ),
+
+        new DoubProp<ThermistorBase>("Max_Temp", tr("Maximum Value"), "ºC"
+                                    , this, &ThermistorBase::maxVal, &ThermistorBase::setMaxVal ),
+
+        new DoubProp<ThermistorBase>("Dial_Step", tr("Dial Step"), "ºC"
+                                    , this, &ThermistorBase::getStep, &ThermistorBase::setStep )
     }, 0} );
 }
 ThermistorBase::~ThermistorBase(){}
