@@ -10,10 +10,10 @@
 #include "dialed.h"
 #include "dialwidget.h"
 
-class MAINMODULE_EXPORT VarResBase : public Dialed, public eResistor
+class VarResBase : public Dialed, public eResistor
 {
     public:
-        VarResBase( QObject* parent, QString type, QString id );
+        VarResBase( QString type, QString id );
         ~VarResBase();
 
         double maxVal()  { return m_maxVal; }
@@ -26,7 +26,7 @@ class MAINMODULE_EXPORT VarResBase : public Dialed, public eResistor
         void setVal( double val );
 
         double getStep() { return m_step; }
-        void setStep( double step ) { if( step<0 ) step=0;m_step = step ; }
+        void setStep( double step ) { if( step<0 ) step=0; m_step = step ; }
 
         virtual void setLinkedValue( double v, int i=0 ) override;
 
