@@ -25,7 +25,8 @@ ClockBase::ClockBase( QString type, QString id )
     Simulator::self()->addToUpdateList( this );
 
     addPropGroup( { "Hidden1", {
-new BoolProp<ClockBase>( "Running", "","", this, &ClockBase::running, &ClockBase::setRunning ),
+        new BoolProp<ClockBase>("Running", "",""
+                               , this, &ClockBase::running, &ClockBase::setRunning ),
     }, groupHidden} );
 }
 ClockBase::~ClockBase(){}
@@ -48,14 +49,15 @@ void ClockBase::updateStep()
     if( !m_changed ) return;
     m_changed = false;
 
+    Simulator::self()->cancelEvents( this );
+    m_outpin->setOutState( false );
+    m_state = false;
+
     if( m_isRunning )
     {
         m_lastTime = Simulator::self()->circTime();
-        Simulator::self()->cancelEvents( this );
-        Simulator::self()->addEvent( m_stepsPC/2, this );
+        Simulator::self()->addEvent( 1, this );
     }
-    m_outpin->setOutState( false );
-    m_state = false;
 }
 
 void ClockBase::setAlwaysOn( bool on )
