@@ -119,10 +119,10 @@ void Csource::updateStep()
 
     updtProperties();
 
-    m_pin[0]->setEnabled( m_controlPins && !m_linked );
-    m_pin[0]->setVisible( m_controlPins && !m_linked );
-    m_pin[1]->setEnabled( m_controlPins && !m_linked );
-    m_pin[1]->setVisible( m_controlPins && !m_linked );
+    m_pin[0]->setEnabled( m_controlPins && !m_linkedTo );
+    m_pin[0]->setVisible( m_controlPins && !m_linkedTo );
+    m_pin[1]->setEnabled( m_controlPins && !m_linkedTo );
+    m_pin[1]->setVisible( m_controlPins && !m_linkedTo );
 
     if( m_currControl )
     {
@@ -145,7 +145,7 @@ void Csource::updateStep()
         m_pin[3]->stampAdmitance( 1/cero_doub );
     }
 
-    if( !m_controlPins && !m_linked )
+    if( !m_controlPins && !m_linkedTo )
     {
         m_pin[0]->removeConnector();
         m_pin[1]->removeConnector();
@@ -182,10 +182,11 @@ void Csource::setVoltage( double v )
     m_pin[3]->stampCurrent(-curr );
 }
 
-void Csource::setLinked( bool l )
+bool Csource::setLinkedTo( Linker* li )
 {
-    Component::setLinked( l );
+    bool linked = Component::setLinkedTo( li );
     setControlPins( m_controlPins );
+    return linked;
 }
 
 void Csource::setLinkedValue( double v, int i )
@@ -233,7 +234,7 @@ void Csource::setCurrSource( bool c )
 
 void Csource::setControlPins( bool set )
 {
-    int length = (set || m_linked) ? 8 : 10;
+    int length = (set || m_linkedTo) ? 8 : 10;
     m_pin[2]->setLength( length );
     m_pin[3]->setLength( length );
 
@@ -245,7 +246,7 @@ void Csource::setControlPins( bool set )
 void Csource::updtProperties()
 {
     if( !m_propDialog ) return;
-    bool controlled = m_controlPins || m_linked; // Controlled by pins or Linked
+    bool controlled = m_controlPins || m_linkedTo; // Controlled by pins or Linked
 
     m_propDialog->showProp("Voltage"    , !controlled && !m_currSource );
     m_propDialog->showProp("Current"    , !controlled &&  m_currSource );
@@ -267,7 +268,7 @@ void Csource::paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w
 
     QPen pen = p->pen();
 
-    if( m_controlPins && !m_linked )
+    if( m_controlPins && !m_linkedTo )
     {
         pen.setWidth(1);
         p->setPen(pen);
@@ -276,7 +277,7 @@ void Csource::paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w
     pen.setWidth(2);
     p->setPen(pen);
 
-    if( !m_controlPins && !m_linked )
+    if( !m_controlPins && !m_linkedTo )
     {
         p->drawEllipse(-10,-10, 20, 20 );
     }
@@ -305,7 +306,7 @@ void Csource::paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w
         p->drawLine( 0,-6, 0,-2 );
         p->drawLine(-2, 4, 2, 4 );
     }
-    if( m_currControl && m_controlPins && !m_linked )
+    if( m_currControl && m_controlPins && !m_linkedTo )
     {
         pen.setWidthF(0.6);
         p->setPen(pen);
