@@ -12,21 +12,23 @@
 
 #include "doubleprop.h"
 
-Component* CurrSource::construct( QObject* parent, QString type, QString id )
-{ return new CurrSource( parent, type, id ); }
+#define tr(str) simulideTr("CurrSource",str)
+
+Component* CurrSource::construct( QString type, QString id )
+{ return new CurrSource( type, id ); }
 
 LibraryItem* CurrSource::libraryItem()
 {
     return new LibraryItem(
-        tr( "Current Source" ),
+        tr("Current Source"),
         "Sources",
         "cursource.png",
         "Current Source",
         CurrSource::construct );
 }
 
-CurrSource::CurrSource( QObject* parent, QString type, QString id )
-          : VarSource( parent, type, id )
+CurrSource::CurrSource( QString type, QString id )
+          : VarSource( type, id )
 {
     m_pin.resize(1);
     m_pin[0] = m_outPin = new Pin( 0, QPoint(28,16), id+"-outPin", 0, this );
@@ -34,8 +36,11 @@ CurrSource::CurrSource( QObject* parent, QString type, QString id )
     m_unit = "A";
 
     addPropGroup( { tr("Main"), {
-new DoubProp<CurrSource>( "Value_Amp",tr("Current Value"),"A", this, &CurrSource::getVal,   &CurrSource::setVal ),
-new DoubProp<CurrSource>( "MaxValue" ,tr("Max. Current") ,"A", this, &CurrSource::maxValue, &CurrSource::setMaxValue )
+        new DoubProp<CurrSource>("Value_Amp", tr("Current Value"), "A"
+                                , this, &CurrSource::getVal, &CurrSource::setVal ),
+
+        new DoubProp<CurrSource>("MaxValue", tr("Max. Current"), "A"
+                                , this, &CurrSource::maxValue, &CurrSource::setMaxValue )
     }, 0} );
 
     setShowProp("MaxValue");
