@@ -53,9 +53,14 @@ SwitchDip::SwitchDip( QString type, QString id )
     Simulator::self()->addToUpdateList( this );
 
     addPropGroup( { tr("Main"), {
-new IntProp <SwitchDip>("Size"     , tr("Size")      ,"", this, &SwitchDip::size     , &SwitchDip::setSize, propNoCopy,"uint" ),
-new BoolProp<SwitchDip>("Exclusive", tr("Exclusive") ,"", this, &SwitchDip::exclusive, &SwitchDip::setExclusive ),
-new BoolProp<SwitchDip>("CommonPin", tr("Common Pin"),"", this, &SwitchDip::commonPin, &SwitchDip::setCommonPin ),
+        new IntProp <SwitchDip>("Size", tr("Size"), ""
+                               , this, &SwitchDip::size, &SwitchDip::setSize, propNoCopy,"uint" ),
+
+        new BoolProp<SwitchDip>("Exclusive", tr("Exclusive"), ""
+                               , this, &SwitchDip::exclusive, &SwitchDip::setExclusive ),
+
+        new BoolProp<SwitchDip>("CommonPin", tr("Common Pin"), ""
+                               , this, &SwitchDip::commonPin, &SwitchDip::setCommonPin ),
     }, groupNoCopy } );
 
     addPropGroup( {"Hidden", {
