@@ -324,8 +324,8 @@ void Connector::remove()
 {
     if( Simulator::self()->isRunning() )  CircuitWidget::self()->powerCircOff();
 
-    if( m_startPin ) m_startPin->remove();
-    if( m_endPin )   m_endPin->remove();
+    if( m_startPin ) m_startPin->connectorRemoved();
+    if( m_endPin )   m_endPin->connectorRemoved();
     remLines();
 }
 
@@ -352,11 +352,11 @@ void Connector::splitCon( int index, Pin* pin0, Pin* pin2 )
 
     QString id = "Connector-"+Circuit::self()->newConnectorId();
     Connector* con0 = new Connector( "Connector", id, m_startPin );
-    Circuit::self()->conList()->insert( con0 );
+    Circuit::self()->conList()->append( con0 );
 
     id = "Connector-"+Circuit::self()->newConnectorId();
     Connector* con1 = new Connector( "Connector", id, pin2 );
-    Circuit::self()->conList()->insert( con1 );
+    Circuit::self()->conList()->append( con1 );
 
     disconnectLines( index-1, index );
     Connector* con = con0;
@@ -381,9 +381,14 @@ void Connector::splitCon( int index, Pin* pin0, Pin* pin2 )
 
 void Connector::updateLines()
 {
-    eNode* enode = startPin()->getEnode();
+    for( ConnectorLine* line : m_conLineList ) line->update();
+
+    /*eNode* enode = startPin()->getEnode();
     if( enode && enode->voltchanged() )
-    { for( ConnectorLine*  line : m_conLineList ) line->update(); }
+    {
+        enode->setVoltChanged( false );
+        for( ConnectorLine* line : m_conLineList ) line->update();
+    }*/
 }
 
 void Connector::setIsBus( bool bus )
