@@ -10,7 +10,7 @@
 #include "e-element.h"
 #include "dialwidget.h"
 
-class MAINMODULE_EXPORT Dialed : public Component
+class Dialed : public Component
 {
     public:
         Dialed( QString type, QString id );
@@ -22,11 +22,10 @@ class MAINMODULE_EXPORT Dialed : public Component
         void setSlider( bool s );
 
         double scale() { return m_dialW.scale(); }
-        void setScale( double s ) { m_dialW.setScale(s); updateProxy(); }
+        void setScale( double s );
 
         virtual void setHidden( bool hid, bool hidArea=false, bool hidLabel=false ) override;
 
-        virtual void setLinked( bool l ) override;
         virtual void setLinkedValue( double v, int i=0 ) override;
 
     public slots:
