@@ -48,10 +48,10 @@ void IoPin::initialize()
 {
     m_step = 0;
     m_steps = Simulator::self()->slopeSteps();
-    m_inpState = false;
-    m_outState = false;
+
+    m_inpState  = false;
+    m_outState  = false;
     m_nextState = false;
-    updateStep();
 }
 
 void IoPin::stamp()
@@ -62,6 +62,30 @@ void IoPin::stamp()
     ePin::createCurrent();
     setPinMode( m_pinMode );
     stampAll();
+    updateStep();
+}
+
+void IoPin::updateStep()
+{
+    if( m_unused ) return;
+
+    if( m_stateZ ) m_pinState = undef_state;
+    else{
+        bool state = getInpState();
+        if( m_inverted ) state = !state;
+        switch( m_pinMode ) // Pin colors in animation
+        {
+            case undef_mode: m_pinState = undef_state; break;
+            case input:  m_pinState = state? input_high : input_low; break;
+            case openCo:{
+                    pinState_t low = m_outState ? driven_low : open_low;
+                    m_pinState = state? open_high  : low ;
+                }break;
+            case output:
+            case source: m_pinState = state? out_high : out_low; break;
+        }
+    }
+    update();
 }
 
 void IoPin::runEvent()
@@ -130,7 +154,6 @@ void IoPin::setPinMode( pinMode_t mode )
         case input:
             m_vddAdmit = 0;
             m_gndAdmit = 1/m_inputImp;
-            setPinState( input_low );
             break;
         case output:
             m_admit = 1/m_outputImp;
@@ -168,13 +191,6 @@ bool IoPin::getInpState()
     if     ( volt > m_inpHighV ) m_inpState = true;
     else if( volt < m_inpLowV )  m_inpState = false;
 
-    if( m_pinMode == openCo )
-    {
-        pinState_t low = m_outState ? driven_low : open_low;
-        setPinState( m_inpState? open_high  : low ); // High : Low colors
-    }
-    else if( m_pinMode == input  ) setPinState( m_inpState? input_high : input_low  ); // High : Low colors
-
     return m_inverted ? !m_inpState : m_inpState;
 }
 
@@ -187,22 +203,10 @@ void IoPin::setOutState( bool high ) // Set Output to Hight or Low
 
     if( m_pinMode == openCo )
     {
-        if( high ){
-            m_gndAdmit = 1/1e8;
-            setPinState( open_high ); // Z-high colors
-         }else{
-            m_gndAdmit = 1/m_outputImp;
-            setPinState( open_low );  // Z-Low colors
-        }
+        m_gndAdmit = high ? 1/1e8 : 1/m_outputImp;
         updtState();
     }else{
-        if( high ){
-            m_outVolt = m_outHighV;
-            setPinState( out_high ); // High colors
-        }else{
-            m_outVolt = m_outLowV;
-            setPinState( out_low ); // Low colors
-        }
+        m_outVolt = high ? m_outHighV : m_outLowV;
         stampVolt( m_outVolt );
 }   }
 
@@ -211,8 +215,7 @@ void IoPin::setStateZ( bool z )
     m_stateZ = z;
     if( z ){
         m_outVolt = m_outLowV;
-        setImp( m_openImp );
-        setPinState( undef_state );
+        setImpedance( m_openImp );
     }else {
         pinMode_t pm = m_pinMode; // Force old pinMode
         m_pinMode = undef_mode;
@@ -234,7 +237,7 @@ void IoPin::setPullup( bool up )
     if( m_pinMode < output ) updtState();
 }
 
-void IoPin::setImp( double imp )
+void IoPin::setImpedance( double imp )
 {
     m_admit = 1/imp;
     stampAll();
@@ -253,7 +256,11 @@ void IoPin::setInputImp( double imp )
 void IoPin::setOutputImp( double imp )
 {
     m_outputImp = imp;
-    if( m_pinMode == output ) m_vddAdmit = 1/m_outputImp;
+    if( m_pinMode == output )
+    {
+        m_vddAdmit = 1/m_outputImp;
+        updtState();
+    }
 }
 
 void IoPin::setInverted( bool inverted )
@@ -309,8 +316,8 @@ void IoPin::registerScript( asIScriptEngine* engine )
                                    , asMETHODPR( IoPin, setVoltage, (double), void)
                                    , asCALL_THISCALL );
 
-    engine->RegisterObjectMethod("IoPin", "void setImp( double imp )"
-                                   , asMETHODPR( IoPin, setImp, (double), void)
+    engine->RegisterObjectMethod("IoPin", "void setImpedance( double imp )"
+                                   , asMETHODPR( IoPin, setImpedance, (double), void)
                                    , asCALL_THISCALL );
 
     engine->RegisterObjectMethod("IoPin", "void changeCallBack(eElement@ p, bool s)"
