@@ -43,14 +43,17 @@ EditorWidget::EditorWidget( QWidget* parent )
     readSettings();
 
     addPropGroup( { tr("Editor Settings"), {
-new IntProp <EditorWidget>("FontSize" , tr("Font Size"),"_Pixels", this,
-                        &EditorWidget::fontSize,    &EditorWidget::setFontSize, 0 ),
-new IntProp <EditorWidget>("TabSize"  , tr("Tab Size"),"_Spaces", this,
-                        &EditorWidget::tabSize,    &EditorWidget::setTabSize, 0 ),
-new BoolProp<EditorWidget>("SpaceTabs", tr("Tabs as spaces"),"", this
-                        , &EditorWidget::spaceTabs, &EditorWidget::setSpaceTabs ),
-new BoolProp<EditorWidget>("ShowSpaces", tr("Show Spaces and Tabs"),"", this
-                        , &EditorWidget::showSpaces, &EditorWidget::setShowSpaces ),
+        new IntProp <EditorWidget>("FontSize", tr("Font Size"),"_px"
+                                  , this,&EditorWidget::fontSize, &EditorWidget::setFontSize, 0 ),
+
+        new IntProp <EditorWidget>("TabSize", tr("Tab Size"),""
+                                  , this, &EditorWidget::tabSize, &EditorWidget::setTabSize, 0 ),
+
+        new BoolProp<EditorWidget>("SpaceTabs", tr("Tabs as spaces"),""
+                                  , this, &EditorWidget::spaceTabs, &EditorWidget::setSpaceTabs ),
+
+        new BoolProp<EditorWidget>("ShowSpaces", tr("Show Spaces and Tabs"),""
+                                  , this, &EditorWidget::showSpaces, &EditorWidget::setShowSpaces ),
     }, 0} );
 }
 EditorWidget::~EditorWidget(){}
@@ -71,7 +74,7 @@ void EditorWidget::setTabSize( int size )
     m_tabSize = size;
     MainWindow::self()->settings()->setValue( "Editor_tab_size", QString::number(m_tabSize) );
 
-    for( CodeEditor* ce : getCodeEditors() ) ce->setTabStopWidth( m_tabSize*m_fontSize*2/3 );
+    for( CodeEditor* ce : getCodeEditors() ) ce->setTabStopWidth( calcTabstopWidth() );
 }
 
 void EditorWidget::setShowSpaces( bool show )
@@ -144,7 +147,7 @@ void EditorWidget::addDocument(  QString file, bool main  )
 {
     CodeEditor* ce = new CodeEditor( this, &m_outPane );
     ce->setVerticalScrollBar( new scrollWidget( ce, Qt::Vertical ) );
-    ce->setTabStopWidth( m_tabSize*m_fontSize*2/3 );
+    ce->setTabStopWidth( calcTabstopWidth() );
     docShowSpaces( ce );
 
     QString tabString = file.isEmpty() ? tr("NEW") : getFileName(file);
@@ -168,6 +171,13 @@ void EditorWidget::addDocument(  QString file, bool main  )
     }
 }
 
+int EditorWidget::calcTabstopWidth() 
+{
+    QFontMetrics fm( m_font );
+    QString spaces( m_tabSize, QChar(' ') );
+    return fm.horizontalAdvance( spaces );
+}
+
 void EditorWidget::open()
 {
     QString dir = m_lastDir;
@@ -550,7 +560,7 @@ void EditorWidget::enableDebugActs( bool enable )
     loadAct->setEnabled( enable );
 }
 
-void EditorWidget::setStepActs(  bool s )
+void EditorWidget::setStepActs( bool s )
 {
     runAct->setEnabled( s );
     stepAct->setEnabled( s );
