@@ -14,7 +14,7 @@ class QListWidget;
 class QPushButton;
 class QListWidgetItem;
 
-class MAINMODULE_EXPORT FileWidget : public QSplitter
+class FileWidget : public QSplitter
 {
     Q_OBJECT
     
@@ -48,7 +48,7 @@ class MAINMODULE_EXPORT FileWidget : public QSplitter
         
         FileBrowser* m_fileBrowser;
         QListWidget* m_bookmarks;
-        QLineEdit*   m_searchFiles;
+        //QLineEdit*   m_searchFiles;
         QPushButton* m_cdUpButton;
         QLineEdit*   m_path;
 
