@@ -15,6 +15,7 @@
 #include "watcher.h"
 #include "console.h"
 #include "mcu.h"
+#include "utils.h"
 
 #include "scriptprop.h"
 
@@ -26,6 +27,13 @@ ScriptCpu::ScriptCpu( eMcu* mcu )
 {
     m_watcher = NULL;
 
+    m_progWordMask = 0;
+    for( uint i=0; i<mcu->wordSize(); ++i )
+    {
+        m_progWordMask <<= 8;
+        m_progWordMask |= 0xFF;
+    }
+
     // Script functions
     m_reset       = NULL;
     m_voltChanged = NULL;
@@ -133,6 +141,10 @@ ScriptCpu::ScriptCpu( eMcu* mcu )
                                    , asMETHODPR( ScriptCpu, getPropStr, (int,const string), string)
                                    , asCALL_THISCALL );
 
+    m_aEngine->RegisterObjectMethod("ScriptCpu", "void setPropStr( int index, const string p,const string v )"
+                                   , asMETHODPR( ScriptCpu, setPropStr, (int,const string,const string), void)
+                                   , asCALL_THISCALL );
+
     m_aEngine->RegisterObjectMethod("ScriptCpu", "void setLinkedValue( int index, double v, int i )"
                                    , asMETHODPR( ScriptCpu, setLinkedValue, (int,double,int), void)
                                    , asCALL_THISCALL );
@@ -238,15 +250,22 @@ void ScriptCpu::voltChanged()
 {
     if( !m_voltChanged ) return;
 
+#ifndef SIMULIDE_W32 // Defined in .pro file for win32
     m_status = m_vChangedCtx->executeJit0( m_voltChanged );
+#else
+    m_status = callFunction0( m_voltChanged, m_vChangedCtx );
+#endif
     if( m_status != asEXECUTION_FINISHED ) printError( m_vChangedCtx );
 }
 
 void ScriptCpu::runEvent()
 {
     if( !m_runEvent ) return;
-
+#ifndef SIMULIDE_W32 // Defined in .pro file for win32
     m_status = m_runEventCtx->executeJit0( m_runEvent );
+#else
+    m_status = callFunction0( m_runEvent, m_runEventCtx );
+#endif
     if( m_status != asEXECUTION_FINISHED ) printError( m_runEventCtx );
 }
 
@@ -262,7 +281,11 @@ void ScriptCpu::runStep()
 {
     if( !m_runStep ) return;
     m_mcu->cyclesDone = 1;
+#ifndef SIMULIDE_W32 // Defined in .pro file for win32
     m_status = m_runStepCtx->executeJit0( m_runStep );
+#else
+    m_status = callFunction0( m_runStep, m_runStepCtx );
+#endif
     if( m_status != asEXECUTION_FINISHED ) printError( m_runStepCtx );
 }
 
@@ -270,7 +293,11 @@ void ScriptCpu::extClock( bool clkState )
 {
     if( m_extClockF )
     {
+#ifndef SIMULIDE_W32 // Defined in .pro file for win32
         m_status = m_extClockCtx->executeJit0( m_extClockF );
+#else
+        m_status = callFunction0( m_extClockF , m_extClockCtx );
+#endif
         if( m_status != asEXECUTION_FINISHED ) printError( m_extClockCtx );
     }
     if( !m_extClock ) return;
@@ -282,6 +309,7 @@ void ScriptCpu::extClock( bool clkState )
 
 void ScriptCpu::command( QString c )
 {
+    if( c.isEmpty() ) return;
     if( !m_command ) return;
 
     prepare( m_command );
@@ -347,9 +375,9 @@ QString ScriptCpu::getStrReg( QString val )
     return QString::fromStdString( str );
 }
 
-void ScriptCpu::addProperty( QString group, QString name, QString type )
+void ScriptCpu::addProperty( QString group, QString name, QString type, QString unit )
 {
-    ComProperty* p = new ScriptProp<ScriptCpu>( name, name, "", this
+    ComProperty* p = new ScriptProp<ScriptCpu>( name, name, unit, this
                                               , &ScriptCpu::getProp, &ScriptCpu::setProp, type );
     m_scriptProps.push_back( p );
 
@@ -413,11 +441,16 @@ void ScriptCpu::setProp( ComProperty* p, QString val )
         std::string str = val.toStdString();
         m_context->SetArgObject( 0, &str );
     }
-    else if( type == "int"    ) m_context->SetArgDWord(  0, val.toInt() );
-    else if( type == "uint"   ) m_context->SetArgDWord(  0, val.toUInt() );
-    else if( type == "double" ) m_context->SetArgDouble( 0, val.toDouble() );
     else if( type == "bool"   ) m_context->SetArgByte(   0, val == "true" );
-
+    else{
+        double multiplier = 1;
+        QStringList l = val.split(" ");
+        val = l.first();
+        if( l.size() > 1 ) multiplier = getMultiplier( l.at(1) );
+        if     ( type == "int"    ) m_context->SetArgDWord(  0, val.toInt()*multiplier );
+        else if( type == "uint"   ) m_context->SetArgDWord(  0, val.toUInt()*multiplier );
+        else if( type == "double" ) m_context->SetArgDouble( 0, val.toDouble()*multiplier );
+    }
     execute();
 }
 
@@ -425,8 +458,8 @@ void ScriptCpu::addEvent( uint time ) { Simulator::self()->addEvent( time, this
 void ScriptCpu::cancelEvents()        { Simulator::self()->cancelEvents( this ); }
 uint64_t ScriptCpu::circTime()        { return Simulator::self()->circTime(); }
 
-int  ScriptCpu::readPGM( uint addr )         { if( addr < m_progSize       ) return m_progMem[addr]; return -1; }
-void ScriptCpu::writePGM( uint addr, int v ) { if( addr < m_progSize       ) m_progMem[addr] = v; }
+int  ScriptCpu::readPGM( uint addr )         { if( addr < m_progSize       ) return m_progMem[addr] & m_progWordMask ; return -1; }
+void ScriptCpu::writePGM( uint addr, int v ) { if( addr < m_progSize       ) m_progMem[addr] = v & m_progWordMask; }
 int  ScriptCpu::readRAM( uint addr )         { if( addr <= m_dataMemEnd    ) return m_dataMem[addr]; return -1; }
 void ScriptCpu::writeRAM( uint addr, int v ) { SET_RAM( addr, v ); }
 int  ScriptCpu::readROM( uint addr )         { if( addr < m_mcu->romSize() ) return m_mcu->getRomValue( addr ); return -1; }
@@ -471,10 +504,18 @@ string ScriptCpu::getPropStr( int index, const string p  )
     Component* comp = m_mcuComp->getLinkedComp( index );
     if( !comp ) return "";
 
-    QString propValue = comp->getPropStr( QString::fromStdString( p) );
+    QString propValue = comp->getPropStr( QString::fromStdString(p) );
     return propValue.toStdString();
 }
 
+void ScriptCpu::setPropStr( int index, const string p, const string v ) // Script should call this in updateStep()
+{
+    Component* comp = m_mcuComp->getLinkedComp( index );
+    if( !comp ) return;
+
+    comp->setPropStr( QString::fromStdString(p), QString::fromStdString(v) );
+}
+
 void ScriptCpu::setLinkedValue( int index, double v, int i )
 {
     Component* comp = m_mcuComp->getLinkedComp( index );
@@ -494,9 +535,10 @@ void ScriptCpu::setLinkedString( int index, string str, int i )
 void ScriptCpu::setLinkedVal( double v, int i )
 {
     if( !m_setLinkedVal ) return;
+    if( !Simulator::self()->isRunning() ) return;
 
-    prepare( m_setLinkedVal);
-    m_context->SetArgDWord( 0, v );
+    prepare( m_setLinkedVal );
+    m_context->SetArgDouble( 0, v );
     m_context->SetArgDWord( 1, i );
     execute();
 }
@@ -504,6 +546,7 @@ void ScriptCpu::setLinkedVal( double v, int i )
 void ScriptCpu::setLinkedStr( QString s, int i )
 {
     if( !m_setLinkedStr ) return;
+    if( !Simulator::self()->isRunning() ) return;
 
     prepare( m_setLinkedStr);
     std::string str = s.toStdString();
