@@ -97,7 +97,7 @@ Mcu::Mcu( QString type, QString id )
     m_autoLoad = false;
     m_scripted = false;
     m_resetPol = false;
-    m_linker   = true;
+    m_isLinker = true;
 
     m_extFreq = 0;
 
@@ -176,8 +176,7 @@ Mcu::Mcu( QString type, QString id )
         }
         if( !dataFile.exists() || !pkgeFile.exists() )
         {
-            MessageBoxNB( "Mcu::Mcu", "                               \n"+
-                      tr("Files not found for: %1").arg( m_device ) );
+            qDebug() << "Mcu::Mcu Files not found for:" << m_device;
             m_error = 1;
             return;
         }
