@@ -13,7 +13,7 @@
 #include "e-element.h"
 
 
-class MAINMODULE_EXPORT ScriptModule : public eElement
+class ScriptModule : public eElement
 {
     public:
         ScriptModule( QString name );
@@ -28,6 +28,7 @@ class MAINMODULE_EXPORT ScriptModule : public eElement
         asIScriptContext* context() { return m_context; }
 
         void callFunction( asIScriptFunction* func );
+        int callFunction0( asIScriptFunction* func, asIScriptContext* context );
         inline void prepare( asIScriptFunction* func ) { m_context->Prepare( func ); }
         void execute();
 
