@@ -29,7 +29,7 @@ class Socket;
 class eNode;
 class CircMatrix;
 
-class MAINMODULE_EXPORT Simulator : public QObject
+class Simulator : public QObject
 {
         friend class eNode;
 
@@ -53,7 +53,7 @@ class MAINMODULE_EXPORT Simulator : public QObject
         uint64_t fps() { return m_fps; }
         void setFps( uint64_t fps );
         uint64_t psPerFrame() { return m_psPF; }
-        uint64_t realPsPF() { return m_realPsPF; }
+        uint64_t simPsPF() { return m_simPsPF; }
 
         uint64_t psPerSec() { return m_psPerSec; } // Speed picosecond/second
         void setPsPerSec( uint64_t psPs );
@@ -114,8 +114,8 @@ class MAINMODULE_EXPORT Simulator : public QObject
 
         inline void clearEventList();
 
-        inline void stopTimer();
-        inline void initTimer();
+        //inline void stopTimer();
+        //inline void initTimer();
 
         eElement* m_firstEvent;
 
@@ -148,8 +148,8 @@ class MAINMODULE_EXPORT Simulator : public QObject
         int m_timerId;
         int m_timerTick_ms;
         int m_slopeSteps;
-        uint m_updtCnt;
 
+        double m_realFPS;
         uint64_t m_fps;
         uint32_t m_NLstep;
         uint32_t m_maxNlstp;
@@ -159,9 +159,10 @@ class MAINMODULE_EXPORT Simulator : public QObject
         uint64_t m_stepSize;  ///
         uint64_t m_stepsPS;   ///
         uint64_t m_psPF;
-        uint64_t m_realPsPF;
+        uint64_t m_simPsPF;
         double   m_realSpeed;
 
+        uint64_t m_timerTime;
         uint64_t m_circTime;
         uint64_t m_tStep;
         uint64_t m_lastStep;
@@ -169,6 +170,7 @@ class MAINMODULE_EXPORT Simulator : public QObject
         uint64_t m_lastRefT;
         uint64_t m_loopTime;
         uint64_t m_guiTime;
+        uint64_t m_updtTime;
         double   m_simLoad;
 
         QElapsedTimer m_RefTimer;
