@@ -7,6 +7,7 @@
 #define UTILS_H
 
 #include <QtMath>
+#include <QList>
 
 class QDomDocument;
 class QByteArray;
@@ -56,16 +57,18 @@ void MessageBoxNB( const QString &title, const QString &message );
 
 //---------------------------------------------------
 
-QString addQuotes( const QString &string );
+QString addQuotes( QString string );
 QString remQuotes( QString string );
-QString getBareName( const QString &filepath );
-QString getFileName( const QString &filepath );
-QString getFileDir( const QString &filepath );
-QString getFileExt( const QString &filepath );
-QString changeExt( const QString &filepath, const QString &ext );
+QString getBareName( QString filepath );
+QString getFileName( QString filepath );
+QString getFileDir( QString filepath );
+QString getFileExt( QString filepath );
+QString changeExt( QString filepath, QString ext );
 
 QString getDirDialog( QString msg, QString oldPath );
 
+QString findFile( QString dir, QString fileName );
+
 //---------------------------------------------------
 
 QDomDocument fileToDomDoc( const QString &fileName, const QString &caller );
@@ -88,5 +91,14 @@ bool lessPinY( Pin* pinA, Pin* pinB );
 QPointF getPointF( QString p );
 QString getStrPointF( QPointF p );
 
+//---------------------------------------------------
+
+template <typename T>
+QList<T> substract( QList<T> &l0, QList<T> &l1 ) // returns l0-l1
+{
+    QList<T> list;
+    for( T el : l0 ) if( !l1.contains( el ) ) list.append( el );
+    return list;
+}
 #endif
 
